
# HG changeset patch
# User Sam Lantinga <slouken@libsdl.org>
# Date 1524545759 25200
# Node ID 28be2719184c8177899d96b696bcf5e28451266f
# Parent  2a7839691e3d88c0480c4a855126d5fa03f9ff6a
Fixed bug 4144 - CMake complains about trailing spaces in sdl2.pc

 Azamat H. Hackimov

When you try use SDL2 2.0.8 in CMake project in Linux, it complains about trailing spaces in sdl2.pc:

CMake Error at CMakeLists.txt:147 (add_executable):
  Target "TestSimpleMain" links to item "-L/usr/lib64 -lSDL2 " which has
  leading or trailing whitespace.  This is now an error according to policy
  CMP0004.

diff -r 2a7839691e3d -r 28be2719184c configure
--- a/configure	Mon Apr 23 21:50:03 2018 -0700
+++ b/configure	Mon Apr 23 21:55:59 2018 -0700
@@ -15752,10 +15752,17 @@
 #    fi
 #done
 SDL_CFLAGS="$BASE_CFLAGS"
-SDL_LIBS="-lSDL2 $BASE_LDFLAGS"
-CPPFLAGS="$CPPFLAGS $EXTRA_CFLAGS"
-CFLAGS="$CFLAGS $EXTRA_CFLAGS"
-LDFLAGS="$LDFLAGS $EXTRA_LDFLAGS"
+SDL_LIBS="-lSDL2"
+if  "$BASE_LDFLAGS" != "" ; then
+    SDL_LIBS="$SDL_LIBS $BASE_LDFLAGS"
+fi
+if  "$EXTRA_CFLAGS" != "" ; then
+    CPPFLAGS="$CPPFLAGS $EXTRA_CFLAGS"
+    CFLAGS="$CFLAGS $EXTRA_CFLAGS"
+fi
+if  "$EXTRA_LDFLAGS" != "" ; then
+    LDFLAGS="$LDFLAGS $EXTRA_LDFLAGS"
+fi
 
 base_libdir=`echo \${libdir} | sed 's/.*\/\(.*\)/\1/; q'`
 
diff -r 2a7839691e3d -r 28be2719184c configure.in
--- a/configure.in	Mon Apr 23 21:50:03 2018 -0700
+++ b/configure.in	Mon Apr 23 21:55:59 2018 -0700
@@ -123,10 +123,17 @@
 #    fi
 #done
 SDL_CFLAGS="$BASE_CFLAGS"
-SDL_LIBS="-lSDL2 $BASE_LDFLAGS"
-CPPFLAGS="$CPPFLAGS $EXTRA_CFLAGS"
-CFLAGS="$CFLAGS $EXTRA_CFLAGS"
-LDFLAGS="$LDFLAGS $EXTRA_LDFLAGS"
+SDL_LIBS="-lSDL2"
+if [ "$BASE_LDFLAGS" != "" ]; then
+    SDL_LIBS="$SDL_LIBS $BASE_LDFLAGS"
+fi
+if [ "$EXTRA_CFLAGS" != "" ]; then
+    CPPFLAGS="$CPPFLAGS $EXTRA_CFLAGS"
+    CFLAGS="$CFLAGS $EXTRA_CFLAGS"
+fi
+if [ "$EXTRA_LDFLAGS" != "" ]; then
+    LDFLAGS="$LDFLAGS $EXTRA_LDFLAGS"
+fi
 
 dnl set this to use on systems that use lib64 instead of lib
 base_libdir=`echo \${libdir} | sed 's/.*\/\(.*\)/\1/; q'`

